#
# spec file for package wingpanel-indicator-bluetooth
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appid io.elementary.desktop.wingpanel.bluetooth
Name:           wingpanel-indicator-bluetooth
Version:        8.0.0
Release:        1.1
Summary:        Wingpanel Bluetooth Indicator
License:        LGPL-2.1-or-later
URL:            https://github.com/elementary/wingpanel-indicator-bluetooth
Source:         %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(granite)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(wingpanel)

%description
A bluetooth indicator for Wingpanel.

%lang_package

%prep
%autosetup

%build
%meson
%meson_build

%install
%meson_install
%find_lang bluetooth-indicator
%fdupes %{buildroot}

%files
%license COPYING
%doc README.md
%dir %{_libdir}/wingpanel
%{_libdir}/wingpanel/libbluetooth.so
%{_datadir}/glib-2.0/schemas/%{appid}.gschema.xml
%{_datadir}/metainfo/io.elementary.wingpanel.bluetooth.metainfo.xml

%files lang -f bluetooth-indicator.lang

%changelog
* Thu Aug 22 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 8.0.0:
  * Updated translations
- update to 7.0.1:
  * Manually add resourced icons to path
- update to 7.0.0:
  * Bluetooth sharing
  * Bluetooth: Fix gettext format
  * Use GLib.Markup.printf_escaped when possible
  * BtSender: Provide feedback when transfer blocked
  * Keep list of active transfers and ensure device widgets show any ongoing transfers
  * Revert "Improved response to power state changes in Switchboard
- update to 2.1.8:
  * Improve restoring Bluetooth state on restart and resuming from suspend
  * Updated translations
- update to 2.1.7:
  * Add tooltip on hover
  * Add a fallback device name for headphones
  * Updated translations
- update to 2.1.6:
  * Prevent showing duplicate devices
  * Fix animated icon when disabling Bluetooth
  * Fallback device names to their device type instead of "(null)"
  * Updated translations
- update to 2.1.5:
  * Updated translations
- switch url to github, as we don't want to link to a different OS
- change license as upstream was always LGPL-2.1+
* Mon Nov 25 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.1.4
  * Updated translations
* Thu May 30 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.1.3:
  * Device: add status images (#78)
  * DisplayWidget: Fix warning caused by a typo (#76)
  * PopoverWidget: Use a listbox for devices and sort (#75)
  * Always enable use of fallback icon (#72)
  * Escape device name (#70)
  * Merge branch 'origin/master' into Weblate
  * Spelling: Bluetooth, BT indicator signal (#67)
* Mon Mar  4 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.1.2:
  * Device: Fix bold device names (#66)
  * Meson: Use GLib preset for l10n
* Thu Nov  8 2018 Alexei Podvalsky <avvissu@yandex.by>
- Add regex for filtering provided libraries
* Mon Oct  8 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.1.1
* Tue Jun 12 2018 avvissu@yandex.by
- Update to 2.1.0:
  * RDNN (#63)
  * Remove unused gschema gettext domain
  * Add editorconfig file
  * Fix freeze if power off when connected. (#60)
  * Lose style_context private member; modify style_context
    before setting icon (#58)
  * Manager.vala: Remove unused methods (#55)
  * Fix deprecation warnings with get_active () (#54)
  * PopoverWidget: Use Revealer when add/remove devices (#46)
  * Get rid of unnecessary close request signal (#47)
  * Update to latest wingpanel API (#52)
  * Device.vala: GObject-style (#45)
  * PopoverWidget: use native Gtk.ScrolledWindow (#49)
  * DisplayWidget: GObject-style (#50)
  * Consistently namespace everything as BluetoothIndicator (#51)
  * PopoverWidget: Use granite style constant (#48)
  * Update copyright headers (#44)
  * Indicator.vala: Use GObject style (#43)
  * Remove CMake (#39)
  * Removed useless content and link to deprecated utility (#38)
  * Install settings schema (#36)
  * Use Gtk.ModelButton (#35)
  * Meson: Add a var for gettext name (#33)
  * Animate disabled slashie (#30)
  * Add deps to README (#32)
  * Add meson build support (#31)
* Sat Jun  9 2018 avvissu@yandex.by
- Switch to github
- Switch to meson
- Add README files
- Spec file cleanup
* Mon Aug 21 2017 avvissu@yandex.by
- Update to 2.0.3:
  * Add Repology and Weblate badges to README.md (#26)
  * Create COPYING (#25)
  * Create CODE_OF_CONDUCT.md (#24)
  * Fixed: Duplicated bluetooth devices (#17)
  * Move separator out of the device list (#18)
- Change the sourceurl to git
* Tue May 23 2017 avvissu@yandex.by
- Update to 2.0.2:
  * {2.0.2} Release 2.0.2
  * Fixes screenshot being included in the installation folder
    (#20)
  * [merge] Add screenshot
  * Pad screenshot
  * Add screenshot
  * Fix Services namespace (#15)
  * [merge] Merge pull request #12 from elementary/travis
  * Add .travis.yml
  * Create README.md
  * Fix DBus binding of org.bluez.Adapter1 and org.bluez.Device1
  * [merge] Don't disconnect if this is not required
  * Don't disconnect if this is not required
* Tue Jan 24 2017 avvissu@yandex.by
- Update to 2.0.1:
  * check global state to fix toggling adapter twice
  * Launchpad automatic translations update.
  * Use Preferences URL spec to launch settings pane
* Mon Sep 19 2016 avvissu@yandex.by
- Update to 2.0
- Spec file cleanup
* Mon Sep 21 2015 and.november@opensuse.org
- initial package (version 0.1) for openSUSE
